<?php
/**
 * Theia Lite Admin Class.
 *
 * @author  Gecodigital
 * @package Theia Lite
 * @since   1.2.8
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Theia_Lite_Admin' ) ) :

/**
 * Theia_Lite_Admin Class.
 */
class Theia_Lite_Admin {

	/**
	 * Constructor.
	 */
	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );
		add_action( 'wp_loaded', array( __CLASS__, 'hide_notices' ) );
		add_action( 'load-themes.php', array( $this, 'admin_notice' ) );
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_admin_scripts' ) );
	}

	/**
	 * Add admin menu.
	 */
	public function admin_menu() {
		$theme = wp_get_theme( get_template() );
		global $theia_lite_adminpage;
		$theia_lite_adminpage = add_theme_page( esc_html__( 'About', 'theia-lite' ) . ' ' . $theme->display( 'Name' ), esc_html__( 'About', 'theia-lite' ) . ' ' . $theme->display( 'Name' ), 'activate_plugins', 'theia-lite-welcome', array( $this, 'welcome_screen' ) );
	}

	/**
	 * Enqueue styles.
	 */
	public function enqueue_admin_scripts() {
		global $theia_lite_adminpage;
		$screen = get_current_screen();
		if ( $screen->id != $theia_lite_adminpage ) {
			return;
		}
		wp_enqueue_style( 'theia-lite-welcome', get_template_directory_uri() . '/inc/admin/welcome.css', array(), '1.0' );
		wp_enqueue_script( 'theia-lite-admin-panel', get_template_directory_uri() . '/inc/admin/admin-panel.js', array('jquery'), '1.0', true );
	}

	/**
	 * Add admin notice.
	 */
	public function admin_notice() {
		global $pagenow;

		wp_enqueue_style( 'theia-lite-message', get_template_directory_uri() . '/inc/admin/message.css', array(), '1.0' );

		// Let's bail on theme activation.
		if ( 'themes.php' == $pagenow && isset( $_GET['activated'] ) ) {
			add_action( 'admin_notices', array( $this, 'welcome_notice' ) );
			update_option( 'theia_lite_admin_notice_welcome', 1 );

		// No option? Let run the notice wizard again..
		} elseif( ! get_option( 'theia_lite_admin_notice_welcome' ) ) {
			add_action( 'admin_notices', array( $this, 'welcome_notice' ) );
		}
	}

	/**
	 * Hide a notice if the GET variable is set.
	 */
	public static function hide_notices() {
		if ( isset( $_GET['theia-lite-hide-notice'] ) && isset( $_GET['_theia_lite_notice_nonce'] ) ) {
			if ( ! wp_verify_nonce( sanitize_key($_GET['_theia_lite_notice_nonce'] ), 'theia_lite_hide_notices_nonce' ) ) {
				wp_die( esc_html__( 'Action failed. Please refresh the page and retry.', 'theia-lite' ) );
			}

			if ( ! current_user_can( 'manage_options' ) ) {
				wp_die( esc_html__( 'Cheatin&#8217; huh?', 'theia-lite' ) );
			}

			$hide_notice = sanitize_text_field( wp_unslash($_GET['theia-lite-hide-notice'] ));
			update_option( 'theia_lite_admin_notice_' . $hide_notice, 1 );
		}
	}

	/**
	 * Show welcome notice.
	 */
	public function welcome_notice() {
		?>
		<div id="message" class="updated geco-message">
			<a class="geco-message-close notice-dismiss" href="<?php echo esc_url( wp_nonce_url( remove_query_arg( array( 'activated' ), add_query_arg( 'theia-lite-hide-notice', 'welcome' ) ), 'theia_lite_hide_notices_nonce', '_theia_lite_notice_nonce' ) ); ?>"><?php esc_html_e( 'Dismiss', 'theia-lite' ); ?></a>
			<p>
			<?php
			/* translators: 1: start option panel link, 2: end option panel link */
			printf( esc_html__( 'Welcome! Thank you for choosing Theia Lite! To fully take advantage of the best our theme can offer please make sure you visit our %1$swelcome page%2$s.', 'theia-lite' ), '<a href="' . esc_url( admin_url( 'themes.php?page=theia-lite-welcome' ) ) . '">', '</a>' );
			?>
			</p>
			<p class="submit">
				<a class="button-secondary" href="<?php echo esc_url( admin_url( 'themes.php?page=theia-lite-welcome' ) ); ?>"><?php esc_html_e( 'Get started with Theia Lite', 'theia-lite' ); ?></a>
			</p>
		</div>
		<?php
	}

	/**
	 * Intro text/links shown to all about pages.
	 *
	 * @access private
	 */
	private function intro() {
		$theme = wp_get_theme( get_template() );
		?>
		<div class="geco-theme-info">
				<h1>
					<?php esc_html_e('About', 'theia-lite'); ?>
					<?php echo esc_html($theme->get( 'Name' )) ." ". esc_html($theme->get( 'Version' )); ?>
				</h1>

			<div class="welcome-description-wrap">
				<div class="geco-screenshot">
					<img src="<?php echo esc_url( get_template_directory_uri() ) . '/screenshot.png'; ?>" />
				</div>
				<p class="geco-actions">
					<a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'Theme Info', 'theia-lite' ); ?></a>

					<a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'http://demo.gecodigital.com/theia-lite/' ) ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'View Demo', 'theia-lite' ); ?></a>

					<a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'http://demo.gecodigital.com/theia-pro/' ) ); ?>" class="button button-primary docs" target="_blank"><?php esc_html_e( 'View PRO version Demo', 'theia-lite' ); ?></a>

					<a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://wordpress.org/support/theme/theia-lite/reviews/' ) ); ?>" class="button button-secondary docs" target="_blank"><?php esc_html_e( 'Rate this theme', 'theia-lite' ); ?></a>
				</p>
				<div class="about-text"><?php echo esc_html($theme->display( 'Description' )); ?>
				</div>
			</div>
		</div>

		<h2 class="nav-tab-wrapper">
			<a class="nav-tab <?php if ( empty( $_GET['tab'] ) && isset( $_GET['page'] ) && $_GET['page'] == 'theia-lite-welcome' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'theia-lite-welcome' ), 'themes.php' ) ) ); ?>">
				<?php echo esc_html($theme->display( 'Name' )); ?>
			</a>
			<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'documentation' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'theia-lite-welcome', 'tab' => 'documentation' ), 'themes.php' ) ) ); ?>">
				<?php esc_html_e( 'Documentation', 'theia-lite' ); ?>
			</a>
			<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'free_vs_pro' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'theia-lite-welcome', 'tab' => 'free_vs_pro' ), 'themes.php' ) ) ); ?>">
				<?php esc_html_e( 'Free Vs PRO', 'theia-lite' ); ?>
			</a>
			<a class="nav-tab <?php if ( isset( $_GET['tab'] ) && $_GET['tab'] == 'changelog' ) echo 'nav-tab-active'; ?>" href="<?php echo esc_url( admin_url( add_query_arg( array( 'page' => 'theia-lite-welcome', 'tab' => 'changelog' ), 'themes.php' ) ) ); ?>">
				<?php esc_html_e( 'Changelog', 'theia-lite' ); ?>
			</a>
		</h2>
		<?php
	}

	/**
	 * Welcome screen page.
	 */
	public function welcome_screen() {
		$current_tab = empty( $_GET['tab'] ) ? 'about' : sanitize_title( wp_unslash($_GET['tab']) );

		// Look for a {$current_tab}_screen method.
		if ( is_callable( array( $this, $current_tab . '_screen' ) ) ) {
			return $this->{ $current_tab . '_screen' }();
		}

		// Fallback to about screen.
		return $this->about_screen();
	}

	/**
	 * Output the about screen.
	 */
	public function about_screen() {
		$theme = wp_get_theme( get_template() );
		?>
		<div class="wrap about-wrap">

			<?php $this->intro(); ?>

			<div class="changelog point-releases">
				<div class="under-the-hood two-col">
					<div class="col">
						<h3><?php esc_html_e( 'Theme Customizer', 'theia-lite' ); ?></h3>
						<p><?php esc_html_e( 'All Theme Options are available via Customize screen.', 'theia-lite' ) ?></p>
						<p><a href="<?php echo esc_url(admin_url( 'customize.php' )); ?>" class="button button-secondary"><?php esc_html_e( 'Customize', 'theia-lite' ); ?></a></p>
					</div>

					<div class="col">
						<h3><?php esc_html_e( 'Got theme support question?', 'theia-lite' ); ?></h3>
						<p><?php esc_html_e( 'Please put it in our support forum.', 'theia-lite' ) ?></p>
						<p><a target="_blank" href="<?php echo esc_url( 'https://wordpress.org/support/theme/theia-lite/' ); ?>" class="button button-secondary"><?php esc_html_e( 'Support', 'theia-lite' ); ?></a></p>
					</div>

					<div class="col">
						<h3><?php esc_html_e( 'Need more features?', 'theia-lite' ); ?></h3>
						<p><?php esc_html_e( 'Upgrade to PRO version for more exciting features.', 'theia-lite' ) ?></p>
						<p><a target="_blank" href="<?php echo esc_url( 'https://gecodigital.com/downloads/theia-theme/' ); ?>" class="button button-secondary"><?php esc_html_e( 'Info about PRO version', 'theia-lite' ); ?></a></p>
					</div>

					<div class="col">
						<h3>
							<?php
							esc_html_e( 'Translate', 'theia-lite' );
							echo ' ' . esc_html($theme->display( 'Name' ));
							?>
						</h3>
						<p><?php esc_html_e( 'Click below to translate this theme into your own language.', 'theia-lite' ) ?></p>
						<p>
							<a target="_blank" href="<?php echo esc_url( 'http://translate.wordpress.org/projects/wp-themes/theia-lite/' ); ?>" class="button button-secondary">
								<?php
								esc_html_e( 'Translate', 'theia-lite' );
								echo ' ' . esc_html($theme->display( 'Name' ));
								?>
							</a>
						</p>
					</div>
				</div>
			</div>

			<div class="return-to-dashboard geco">
				<?php if ( current_user_can( 'update_core' ) && isset( $_GET['updated'] ) ) : ?>
					<a href="<?php echo esc_url( self_admin_url( 'update-core.php' ) ); ?>">
						<?php is_multisite() ? esc_html_e( 'Return to Updates', 'theia-lite' ) : esc_html_e( 'Return to Dashboard &rarr; Updates', 'theia-lite' ); ?>
					</a> |
				<?php endif; ?>
				<a href="<?php echo esc_url( self_admin_url() ); ?>"><?php is_blog_admin() ? esc_html_e( 'Go to Dashboard &rarr; Home', 'theia-lite' ) : esc_html_e( 'Go to Dashboard', 'theia-lite' ); ?></a>
			</div>
		</div>
		<?php
	}

		/**
	 * Output the changelog screen.
	 */
	public function changelog_screen() {
		global $wp_filesystem;

		?>
		<div class="wrap about-wrap">

			<?php $this->intro(); ?>

			<p class="about-description"><?php esc_html_e( 'View changelog below:', 'theia-lite' ); ?></p>

			<?php
				$changelog_file = apply_filters( 'theia-lite_changelog_file', get_template_directory() . '/readme.txt' );

				// Check if the changelog file exists and is readable.
				if ( $changelog_file && is_readable( $changelog_file ) ) {
					WP_Filesystem();
					$changelog = $wp_filesystem->get_contents( $changelog_file );
					$changelog_list = $this->parse_changelog( $changelog );

					echo wp_kses_post( $changelog_list );
				}
			?>
		</div>
		<?php
	}

	/**
	 * Parse changelog from readme file.
	 * @param  string $content
	 * @return string
	 */
	private function parse_changelog( $content ) {
		$matches   = null;
		$regexp    = '~==\s*Changelog\s*==(.*)($)~Uis';
		$changelog = '';

		if ( preg_match( $regexp, $content, $matches ) ) {
			$changes = explode( '\r\n', trim( $matches[1] ) );

			$changelog .= '<pre class="changelog">';

			foreach ( $changes as $index => $line ) {
				$changelog .= wp_kses_post( preg_replace( '~(=\s*Version\s*(\d+(?:\.\d+)+)\s*=|$)~Uis', '<span class="title">${1}</span>', $line ) );
			}

			$changelog .= '</pre>';
		}

		return wp_kses_post( $changelog );
	}

	/**
	 * Output the free vs pro screen.
	 */
	public function free_vs_pro_screen() {
		?>
		<div class="wrap about-wrap">

			<?php $this->intro(); ?>

			<p class="about-description"><?php esc_html_e( 'Upgrade to PRO version for more exciting features.', 'theia-lite' ); ?></p>

			<table>
				<thead>
					<tr>
						<th class="table-feature-title"><h3><?php esc_html_e('Features', 'theia-lite'); ?></h3></th>
						<th><h3><?php esc_html_e('Theia Lite', 'theia-lite'); ?></h3></th>
						<th><h3><?php esc_html_e('Theia PRO', 'theia-lite'); ?></h3></th>
					</tr>
				</thead>
				<tbody>
					<tr>
						<td><h3><?php esc_html_e('Theme Options made with the Customizer', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Responsive Design', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Change Background', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Logo Upload', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('RTL Support', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('WPML Multilingual ready', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Sticky Menu', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-yes"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Font switcher', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Page Template For Page Builders', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Breadcrumb', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Highlighted Menu Item', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Footer Dynamic', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Woocommerce Compability', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('8 Loading Page', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('7 Shortcodes', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('10 Exclusive Widgets', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Information About Author Box', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Related Posts Box', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Lightbox', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td><h3><?php esc_html_e('Tooltips', 'theia-lite'); ?></h3></td>
						<td><span class="dashicons dashicons-no"></span></td>
						<td><span class="dashicons dashicons-yes"></span></td>
					</tr>
					<tr>
						<td></td>
						<td></td>
						<td>and more...</td>
					</tr>
					<tr>
						<td></td>
						<td></td>
						<td class="btn-wrapper">
							<a href="<?php echo esc_url( apply_filters( 'theia_pro_theme_url', 'http://demo.gecodigital.com/theia-pro/' ) ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'View PRO', 'theia-lite' ); ?></a>
							<a href="<?php echo esc_url( apply_filters( 'theia_pro_theme_url', 'http://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-secondary" target="_blank"><?php esc_html_e( 'More Info', 'theia-lite' ); ?></a>
						</td>
					</tr>
				</tbody>
			</table>

		</div>
		<?php
	}
	/**
	 * Output the documentation screen.
	 */
	public function documentation_screen() {
		?>
		<div class="wrap about-wrap">
			<?php $this->intro(); ?>
			<p class="about-description"><?php esc_html_e( 'Theia Lite WordPress Theme Documentation', 'theia-lite' ); ?></p>
			<div class="option-panel-toggle">
				<div class="singleToggle">
					<span class="dashicons dashicons-arrow-right"></span><div class="toggleTitle"><?php esc_html_e( 'How to add social icons', 'theia-lite' ); ?></div>
					<div class="toggleText">
						<ul>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'Go to your WordPress Dashboard under "Appearance-> Customize-> Theia Social Network". Here you can choose which social network to show.  In the Theia PRO version you can decide where to view them (in the footer section or in header sidebar).', 'theia-lite' ); ?>
								<br/><a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'More Info About PRO Version', 'theia-lite' ); ?></a>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-1.png'; ?>" />
								</div>
							</li>
						</ul>
					</div>
				</div>
			</div>
			<div class="option-panel-toggle">
				<div class="singleToggle">
					<span class="dashicons dashicons-arrow-right"></span><div class="toggleTitle"><?php esc_html_e( 'How to add custom logo', 'theia-lite' ); ?></div>
					<div class="toggleText">
						<ul>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'Go to your WordPress Dashboard under "Appearance-> Customize-> Site Identity". Here you can upload your custom logo.', 'theia-lite' ); ?>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-2.png'; ?>" />
								</div>
							</li>
						</ul>
					</div>
				</div>
			</div>
			<div class="option-panel-toggle">
				<div class="singleToggle">
					<span class="dashicons dashicons-arrow-right"></span><div class="toggleTitle"><?php esc_html_e( 'How to change theme colors', 'theia-lite' ); ?></div>
					<div class="toggleText">
						<ul>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'Go to your WordPress Dashboard under "Appearance-> Customize-> Colors". Here you can change the theme colors.', 'theia-lite' ); ?>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-3.png'; ?>" />
								</div>
							</li>
						</ul>
					</div>
				</div>
			</div>
			<div class="option-panel-toggle">
				<div class="singleToggle">
					<span class="dashicons dashicons-arrow-right"></span><div class="toggleTitle"><?php esc_html_e( 'How to display page loader (available in Theia PRO version)', 'theia-lite' ); ?></div>
					<div class="toggleText">
						<ul>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'This feature is available in Theia PRO version. Go to your WordPress Dashboard under "Appearance-> Customize-> Theia Pro Options-> Header", find the option called "Enable to view Page Loader" and check it.', 'theia-lite' ); ?>
									<br/><a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'More Info About PRO Version', 'theia-lite' ); ?></a>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-4.png'; ?>" />
								</div>
							</li>
						</ul>
					</div>
				</div>
			</div>
			<div class="option-panel-toggle">
				<div class="singleToggle">
					<span class="dashicons dashicons-arrow-right"></span><div class="toggleTitle"><?php esc_html_e( 'Can I use a page builder plugin? (available in Theia PRO version)', 'theia-lite' ); ?></div>
					<div class="toggleText">
						<ul>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'This feature is available in Theia PRO version. Yes, the theme is compatible with Elementor Page Builder, SiteOrigin and Beaver Builder plugins. Just create or edit the page you want to use the page builder and choose the template called "Template for page builders".', 'theia-lite' ); ?>
								<br/><a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'More Info About PRO Version', 'theia-lite' ); ?></a>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-5.png'; ?>" />
								</div>
							</li>
						</ul>
					</div>
				</div>
			</div>
			<div class="option-panel-toggle">
				<div class="singleToggle">
					<span class="dashicons dashicons-arrow-right"></span><div class="toggleTitle"><?php esc_html_e( 'How to highlight a menu item (available in Theia PRO version)', 'theia-lite' ); ?></div>
					<div class="toggleText">
						<ul>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'This feature is available in Theia PRO version. If you need to emphasize a menu item (call to action, donate button, etc..) just go to your WordPress Dashboard under "Appearance-> Menus". Create a new "Custom Links" and drag it into the menu. Expand the entry and in the "CSS Classes" section write: gecoCustomButton', 'theia-lite' ); ?>
								<br/><a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'More Info About PRO Version', 'theia-lite' ); ?></a>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-6.png'; ?>" />
								</div>
							</li>
							<li>
								<div class="theiaDocText">
									<?php esc_html_e( 'This feature is available in Theia PRO version. This will be the result (the colors change according to the ones chosen).', 'theia-lite' ); ?>
								<br/><a href="<?php echo esc_url( apply_filters( 'theia_lite_theme_url', 'https://gecodigital.com/downloads/theia-theme/' ) ); ?>" class="button button-primary" target="_blank"><?php esc_html_e( 'More Info About PRO Version', 'theia-lite' ); ?></a>
								</div>
								<div class="theiaDocImage">
									<img src="<?php echo esc_url( get_template_directory_uri() ) . '/inc/admin/images/theia-documentation-7.png'; ?>" />
								</div>
							</li>
						</ul>
					</div>
				</div>
			</div>
		</div>
		<?php
	}
}

endif;

return new Theia_Lite_Admin();
